<?php
namespace Teknisa\MAN\Controllers;


use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\MAN\Services\CustomizacaoTAAservice;
use Teknisa\MAN\Services\FileUploaderService;
use Zeedhi\Framework\Util\Functions;

class CustomizacaoTAA extends  \Teknisa\MAN\Controllers\TeknisaCrud {
    
    const dataSourceCores           = 'customizacaoTAAcores';
    const dataSourceImagens         = 'customizacaoTAAimagens';
    const dataSourceCoresUnidade    = 'customizacaoTAAcoresUnidade';
    const dataSourceImagensUnidade  = 'customizacaoTAAimagensUnidade';
    const dataSourceCaixas          = 'caixas_associados_config';

    
	protected $dataSourceManager;
	protected $parameterBagColumns = ['NRORG'];
    protected $customizacaoTAAservice;
    protected $fileUploaderService;
    protected $environment;
    protected $utilService;
    
    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, $dataSourceManager, $customizacaoTAAservice, $fileUploaderService, $environment) {
        
        $this->crudService                  = $crudService;
        $this->parameterBag                 = $parameterBag;
        $this->entityManager                = $entityManager;
        $this->utilService                  = $utilService;
        $this->dataSourceManager            = $dataSourceManager;
        $this->fileUploaderService          = $fileUploaderService;
        $this->CustomizacaoTAAservice       = $customizacaoTAAservice;
        $this->environment                  = $environment;
    }

    public function findCores(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $coresPadrao = '{"DSCORPRIMARIA":2189567, "DSCORPRIMARIASUAVE":5348095,"DSCORPRIMARIAESCURA":14020,"DSCORCABECALHO":1728760,"DSCORCATEGORIAS":16777215,"DSCORFONTECATEGORIAS":2039582,"DSCORFUNDOCARRINHO":14803426, "DSCORFONTEPRECO":255}';
        
            $params = ["NRORG" => $this->environment->getNrOrgTrab()];
    
            $result = $this->CustomizacaoTAAservice->findCores($params['NRORG']);
    
            if(isset($result[0]['CORESJSON'])){
               $CORESJSON = [json_decode($result[0]['CORESJSON'])];
               $response->addDataSet(new DataSet(self::dataSourceCores, $CORESJSON));
            } else {
              $CORESJSON = [json_decode($coresPadrao)];
              $response->addDataSet(new DataSet(self::dataSourceCores, $CORESJSON));
            }
        } 
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
        
    }
    
    public function findImagens(DTO\Request\Filter $request, DTO\Response $response) {
         try{
            $params = ["NRORG" => $this->environment->getNrOrgTrab()];
            
            $result = $this->CustomizacaoTAAservice->findImgs($params['NRORG']);
            if(isset($result[0]['JSONB64CUSTOMMEDIA'])){
                $JSONB64CUSTOMMEDIA = [json_decode($result[0]['JSONB64CUSTOMMEDIA'])];
                $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
            } else {
                // $JSONB64CUSTOMMEDIA = [json_decode($statement->fetchAll()[0]['JSONB64CUSTOMMEDIA'])];
                // $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
                return false;
            }
        } 
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveCores(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    $this->dataSourceName = self::dataSourceCores;
    	    $rows = $request->getDataSet()->getRows();
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
            unset($rows[0]['__createdLocal']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsCores = array( 
    	                    'CORESJSON'     =>    $rows[0],
                            'NRORG'                  =>    $NRORG
                        );
            $this->CustomizacaoTAAservice->saveColors($paramsCores);
            $response->addDataSet(new DataSet($this->dataSourceName,array('CORESJSON'=>$paramsCores['CORESJSON'],'NRORG'=>$paramsCores['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveImagens(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    
    	    $this->dataSourceName = self::dataSourceImagens;
    	    $rows = $request->getDataSet()->getRows();
    	    
    	    $NRORG = $rows[0]['NRORG'];
    	    unset($rows[0]['NRORG']);
    	    unset($rows[0]['NRORGULTATU']);
            unset($rows[0]['CDOPERULTATU']);
            unset($rows[0]['DTULTATU']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsImagens = array( 
                'JSONB64CUSTOMMEDIA'     =>    $rows[0],
                'NRORG'                  =>    $NRORG
            );
            $this->CustomizacaoTAAservice->saveImages($paramsImagens);
            $response->addDataSet(new DataSet($this->dataSourceName,array('JSONB64CUSTOMMEDIA'=>$paramsImagens['JSONB64CUSTOMMEDIA'],'NRORG'=>$paramsImagens['NRORG'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveConfig(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        
        $NRORG = isset($conditions['NRORG']) ? $conditions['NRORG'] : null;
    
        // Lista de todos os campos possíveis com valores padrão
        $fields = [
            "urlPerifericos" => "",
            "balancaport" => "",
            "boldPrice" => false,
            "mainLanguage" => [],
            "idiomaAdic_pt_br" => false,
            "idiomaAdic_en" => false,
            "idiomaAdic_es" => false,
            "comprimentoNSU" => null,
            "shouldAutoClose" => false,
            "modeEntrega" => [],
            "modeEntregaDrive" => [],
            "modeloImpressora" => "",
            "portaImpressora" => "US",
            "useAlternativeLayout" => true,
            "slimMode" => false,
            "modotap" => false,
            "modobalanca" => false,
            "isEditMode" => false,
            "exibeContinuarComprando" => false,
            "itemsList" => false,
            "hideGroupOnMax" => false,
            "avancagrupomax" => false,
            "enableProdBarCodeRead" => false,
            "acessibilidade" => false,
            "agruparnaimpressao" => false,
            "produtoSemfoto" => true,
            "exibApartir" => false,
            "removeConfirmImpressaoCupom" => false,
            "cardapioExpira" => false,
            "usePager" => false,
            "allowMultipleAdd" => true,
            "imprimeEspelho" => true,
            "enableSubgroups" => true,
            "permiteObsDigitada" => false,
            "fixedServiceTax" => false,
            "showMinPriceDifference" => false,
            "removTXServTap" => false,
            "aplicaTXServAt" => false,
            "impFichas" => false,
            "timeOut" => 150,
            "timeOutInModal" => 30
        ];
    
        // Preenche os campos com os valores presentes no $conditions
        foreach ($conditions as $key => $value) {
            if (array_key_exists($key, $fields)) {
                if ($value === "S") {
                    $fields[$key] = true;
                } elseif ($value === "N") {
                    $fields[$key] = false;
                } else {
                    $fields[$key] = $value;
                }
            }
        }
        
        // verificacoes adicionais
        if (isset($conditions["mainLanguageCode"]) && isset($conditions["mainLanguageName"])) {
            $fields["mainLanguage"] = [
                [
                    "name" => $conditions["mainLanguageName"],
                    "code" => $conditions["mainLanguageCode"]
                ]
            ];
        }
        
        
        // Verificações adicionais para modeEntrega e modeEntregaDrive
        if (isset($conditions["entregaDrive"]) && $conditions["entregaDrive"] === "S") {
            $fields["modeEntregaDrive"] = ["drive"];
            $fields["modeEntrega"] = [];
        } else {
            $fields["modeEntregaDrive"] = [];
            $fields["modeEntrega"] = [];
            if (isset($conditions["entregaComer"]) && $conditions["entregaComer"] === "S") {
                $fields["modeEntrega"][] = "comer";
            }
            if (isset($conditions["entregaLevar"]) && $conditions["entregaLevar"] === "S") {
                $fields["modeEntrega"][] = "levar";
            }
        }
        
        // Converte o array para JSON
        $jsonConfigString = json_encode($fields, JSON_UNESCAPED_UNICODE);
    
        // Salva o JSON no banco de dados (exemplo fictício)
        $this->CustomizacaoTAAservice->saveJsonConfig($jsonConfigString, $NRORG);
    
        $response->addDataSet(new DataSet("customizacaoTAAconfig",array('jsonConfigString'=>$jsonConfigString,'NRORG'=>$NRORG)));
    }
 
 
    public function findJsonConfig(DTO\Request\Filter $request, DTO\Response $response) {
        // Obtém os parâmetros de filtro do request
        $params = $this->utilService->getParamsAsArray($request);
    
        // Chama o serviço para buscar o JSON config
        $jsonConfig = $this->CustomizacaoTAAservice->findJsonConfig($params['NRORG']);
    
        $response->addDataSet(new DataSet('select_jsonconfig_taa', $jsonConfig));
    }
    
    //Customizações por Unidade/Loja
    public function findConfigsUnidadeLoja(DTO\Request\Filter $request, DTO\Response $response) {
        // Obtém os parâmetros de filtro do request
        $params = $this->utilService->getParamsAsArray($request);
    
        // Chama o serviço para buscar o JSON config
        $jsonConfig = $this->CustomizacaoTAAservice->findConfigsUnidadeLoja();
    
        $response->addDataSet(new DataSet('configsUnidadeLoja', $jsonConfig));
    }
    
    
    public function saveConfigUnidade(DTO\Request\DataSet $request, DTO\Response $response) {
        try{
            $params = $this->utilService->getParamsAsArray($request);
            $conditions = $params[0];

            if(isset($conditions['__is_new'])){
                $images = ['IMGTELADEESPERA', 'IMGLOGO', 'PRODSEMFOTO', 'INSTRUCOESPAGER', 'INSTRUCOESBALANCA', 'INSTRUCOESTAP', 'INSTRUCOESMAQUININHA', 'INSTRUCOESIMPRESSORA', 'ERROIMPRESSORA', 'ERROSALVARVENDA', 'ERROPINPAD', 'ERROPINPAD2', 'LEVAR', 'CONSLOCAL'];
                $arrayImages = array();
                foreach($images as $image) {
                    $arrayImages[$image] = $conditions[$image];
                }
                $conditions['JSONB64CUSTOMMEDIA'] = json_encode($arrayImages);
                $cod = $this->CustomizacaoTAAservice->GETNEWCOD();
                $conditions['CDCONFIGTAA'] = $cod['NEXT_CD'];
                $conditions['JSONCONFIG'] = $this->prepareConfigsUnidade(null);
                $this->CustomizacaoTAAservice->saveConfigUnidade($conditions);
            }else{
                $this->CustomizacaoTAAservice->updateConfigUnidade($conditions);
            }
        }
        catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteConfigUnidade(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $params = $this->utilService->getParamsAsArray($request);
            
            $this->CustomizacaoTAAservice->deleteConfigUnidade($params[0]);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }

    
    //Manipulações de Cor
    
    public function findCoresUnidadesLoja(DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $coresPadrao = '{"DSCORPRIMARIA":2189567, "DSCORPRIMARIASUAVE":5348095,"DSCORPRIMARIAESCURA":14020,"DSCORCABECALHO":1728760,"DSCORCATEGORIAS":16777215,"DSCORFONTECATEGORIAS":2039582,"DSCORFUNDOCARRINHO":14803426, "DSCORFONTEPRECO":255}';
        
            $params = $this->utilService->getParamsAsArray($request);
            
            $result = $this->CustomizacaoTAAservice->findCoresUnidadesLoja($params);
            
            $CORESJSON = isset($result[0]['CORESJSON']) ? [json_decode($result[0]['CORESJSON'])] :  [json_decode($coresPadrao)];

            $response->addDataSet(new DataSet(self::dataSourceCoresUnidade, $CORESJSON));
        } 
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
        
    }
    
    public function saveCoresUnidadeLoja(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    $this->dataSourceName = self::dataSourceCoresUnidade;
    	    $rows = $request->getDataSet()->getRows();
    	    $CDFILIAL       = $rows[0]['CDFILIAL'];
    	    $CDLOJA         = $rows[0]['CDLOJA'];
    	    $CDCONFIGTAA    = $rows[0]['CDCONFIGTAA'];
    	    unset($rows[0]['CDFILIAL']);
    	    unset($rows[0]['CDLOJA']);
    	    unset($rows[0]['CDCONFIGTAA']);
            unset($rows[0]['__createdLocal']);
            unset($rows[0]['__is_new']);
            unset($rows[0]['changed']);
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsCores = array( 
                'CORESJSON'     =>  $rows[0],
                'CDFILIAL'      =>  $CDFILIAL,
                'CDLOJA'        =>  $CDLOJA,
                'CDCONFIGTAA'   =>  $CDCONFIGTAA
            );
            $this->CustomizacaoTAAservice->saveColorsUnidadeLoja($paramsCores);
            $response->addDataSet(new DataSet($this->dataSourceName,array('CORESJSON'=>$paramsCores['CORESJSON'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    //Manipulações de Imagens
    public function findImagensUnidadesLoja(DTO\Request\Filter $request, DTO\Response $response) {
         try{

            $params = $this->utilService->getParamsAsArray($request);
            $result = $this->CustomizacaoTAAservice->findImgsUnidadesLoja($params);
            
            
            if(isset($result[0]['JSONB64CUSTOMMEDIA'])){
                $JSONB64CUSTOMMEDIA = [json_decode($result[0]['JSONB64CUSTOMMEDIA'])];

                $response->addDataSet(new DataSet(self::dataSourceImagensUnidade, $JSONB64CUSTOMMEDIA));
                
            } else {
                // $JSONB64CUSTOMMEDIA = [json_decode($statement->fetchAll()[0]['JSONB64CUSTOMMEDIA'])];
                // $response->addDataSet(new DataSet(self::dataSourceImagens, $JSONB64CUSTOMMEDIA, $params));
                return false;
            }
        } 
        catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function saveImagensUnidadeLoja(DTO\Request\DataSet $request,DTO\Response $response){
    	try {
    	    $this->dataSourceName = self::dataSourceImagensUnidade;
    	    $rows = $request->getDataSet()->getRows();
    	    $CDFILIAL       = $rows[0]['CDFILIAL'];
    	    $CDLOJA         = $rows[0]['CDLOJA'];
    	    $CDCONFIGTAA    = $rows[0]['CDCONFIGTAA'];
    	    unset($rows[0]['NRORGULTATU']);
            unset($rows[0]['CDOPERULTATU']);
            unset($rows[0]['DTULTATU']);
            unset($rows[0]['__is_new']);
            if(isset($rows[0]['changed'])){
                unset($rows[0]['changed']);
            }
    	    $rows[0] = json_encode($rows[0]);
    	    $paramsImagens = array( 
                'JSONB64CUSTOMMEDIA'     =>    $rows[0],
                'CDFILIAL'      =>  $CDFILIAL,
                'CDLOJA'        =>  $CDLOJA,
                'CDCONFIGTAA'   =>  $CDCONFIGTAA
            );
            $this->CustomizacaoTAAservice->saveImagensUnidadeLoja($paramsImagens);
            $response->addDataSet(new DataSet($this->dataSourceName,array('JSONB64CUSTOMMEDIA'=>$paramsImagens['JSONB64CUSTOMMEDIA'])));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    

    //Manipulações de Configurações
    
    public function prepareConfigsUnidade($conditions){
        $fields = [
            "urlPerifericos" => "",
            "balancaport" => "",
            "boldPrice" => false,
            "mainLanguage" => [],
            "idiomaAdic_pt_br" => false,
            "idiomaAdic_en" => false,
            "idiomaAdic_es" => false,
            "comprimentoNSU" => null,
            "shouldAutoClose" => false,
            "modeEntrega" => [],
            "modeEntregaDrive" => [],
            "useAlternativeLayout" => true,
            "slimMode" => false,
            "modobalanca" => false,
            "isEditMode" => false,
            "exibeContinuarComprando" => false,
            "itemsList" => false,
            "hideGroupOnMax" => false,
            "avancagrupomax" => false,
            "enableProdBarCodeRead" => false,
            "acessibilidade" => false,
            "agruparnaimpressao" => false,
            "produtoSemfoto" => true,
            "exibApartir" => false,
            "removeConfirmImpressaoCupom" => false,
            "cardapioExpira" => false,
            "usePager" => false,
            "allowMultipleAdd" => true,
            "imprimeEspelho" => true,
            "enableSubgroups" => true,
            "permiteObsDigitada" => false,
            "fixedServiceTax" => false,
            "showMinPriceDifference" => false,
            "removTXServTap" => false,
            "aplicaTXServAt" => false,
            "impFichas" => false,
            "timeOut" => 150,
            "timeOutInModal" => 30
        ];
        
        $conditions = isset($conditions) ? $conditions : $fields;
        // Preenche os campos com os valores presentes no $conditions
        foreach ($conditions as $key => $value) {
            if (array_key_exists($key, $fields)) {
                if ($value === "S") {
                    $fields[$key] = true;
                } elseif ($value === "N") {
                    $fields[$key] = false;
                } else {
                    $fields[$key] = $value;
                }
            }
        }
        
        // verificacoes adicionais
        if (isset($conditions["mainLanguageCode"]) && isset($conditions["mainLanguageName"])) {
            $fields["mainLanguage"] = [
                [
                    "name" => $conditions["mainLanguageName"],
                    "code" => $conditions["mainLanguageCode"]
                ]
            ];
        }
        
        // Verificações adicionais para modeEntrega e modeEntregaDrive
        if (isset($conditions["entregaDrive"]) && $conditions["entregaDrive"] === "S") {
            $fields["modeEntregaDrive"] = ["drive"];
            $fields["modeEntrega"] = [];
        } else {
            $fields["modeEntregaDrive"] = [];
            $fields["modeEntrega"] = [];
            if (isset($conditions["entregaComer"]) && $conditions["entregaComer"] === "S") {
                $fields["modeEntrega"][] = "comer";
            }
            if (isset($conditions["entregaLevar"]) && $conditions["entregaLevar"] === "S") {
                $fields["modeEntrega"][] = "levar";
            }
        }
        
        // Converte o array para JSON
        $jsonConfigString = json_encode($fields, JSON_UNESCAPED_UNICODE);
        return $jsonConfigString;
    }
    
    public function saveConfigUnidadeLoja(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $jsonConfigString = $this->prepareConfigsUnidade($conditions);
        $conditions['JSONCONFIG'] = $jsonConfigString;
        $this->CustomizacaoTAAservice->saveJsonConfigUnidade($conditions);
    
        $response->addDataSet(new DataSet("configUnidade",array('jsonConfigString'=>$jsonConfigString)));
    }
    
    public function findJsonConfigUnidadeLoja(DTO\Request\Filter $request, DTO\Response $response) {
        // Obtém os parâmetros de filtro do request
        $params = $this->utilService->getParamsAsArray($request);
    
        // Chama o serviço para buscar o JSON config
        $jsonConfig = $this->CustomizacaoTAAservice->findJsonConfigUnidade($params);
    
        $response->addDataSet(new DataSet('configUnidade', $jsonConfig));
    }
    
    
    public function findCaixaConfig(DTO\Request\Filter $request, DTO\Response $response) {
        // Obtém os parâmetros de filtro do request
        $params = $this->utilService->getParamsAsArray($request);
    
        // Chama o serviço para buscar o JSON config
        $result = $this->CustomizacaoTAAservice->findConfigsCaixas($params);
    
        $response->addDataSet(new DataSet('caixas_associados_config', $result));
    }
    
    public function saveCaixaConfig(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = self::dataSourceCaixas;
        try {
            foreach ($request->getDataSet()->getRows() as $row) {
                $arrayCodigoCaixa = $row['CDCAIXA'];
                $row['NMCAIXA'] = $row['NMCAIXA'];
                
                foreach ($arrayCodigoCaixa as $caixa) {
                    $row['CDCAIXA'] = $caixa;
                    $row['__is_new'] = true;
                    $row['changed'] = false;
                    
                    $exists = $this->CustomizacaoTAAservice->findCaixa($row);
                    
                    if($exists[0]['QTD'] == 0){
                        $this->dataSourceManager->persist(new DataSet($this->dataSourceName, array($row)));
                    }
                }
            }
            
            $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteCaixaConfig(DTO\Request\DataSet $request,DTO\Response $response) {
    	try {
            $this->dataSourceName = self::dataSourceCaixas;
            parent::delete($request,$response);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
}
