<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities\Query;
use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;


class CustomizacaoTAAservice {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
		$this->connection = $entityManager->getConnection();
    }
    
    const FIND_CORES = "
    	SELECT CORESJSON, NRORG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
    ";
    
    public function findCores($NRORG) {
        $statement = $this->entityManager->getConnection()->prepare(self::FIND_CORES);
	    $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	    $statement->execute();
	    
        return $result = $statement->fetchAll();
    }
    
    
    const FIND_IMGS = "
    	SELECT JSONB64CUSTOMMEDIA, NRORG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
    ";
    
    public function findImgs($NRORG) {
        $statement = $this->entityManager->getConnection()->prepare(self::FIND_IMGS);
	    $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	    $statement->execute();
	    
        return $result = $statement->fetchAll();
    }

	public function saveColors($paramsCores){
		$checaCores = $this->entityManager->getConnection()->fetchAll(self::CHECK_CORES, $paramsCores);
		
		if (isset(($checaCores[0][1]))){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_COLORS);
			$statement->bindParam(':CORESJSON', $paramsCores['CORESJSON'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsCores['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		else {
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_COLORS);
			$statement->bindParam(':CORESJSON', $paramsCores['CORESJSON'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsCores['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
	}
	
	const CHECK_CORES = "
	SELECT 1 FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	const UPDATE_COLORS = "
	UPDATE CUSTOMIZACAOTAAMOBILE
		SET CORESJSON = :CORESJSON
		WHERE NRORG = :NRORG
	";
	
	const INSERT_COLORS =
	"INSERT INTO CUSTOMIZACAOTAAMOBILE
	(CORESJSON, NRORG)
	VALUES
	(:CORESJSON, :NRORG)
	";
	
	public function saveImages($paramsImagens){
		$checaImagens = $this->entityManager->getConnection()->fetchAll(self::CHECK_IMAGES, $paramsImagens);
		if(isset($checaImagens[0])){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_IMAGES);
			$statement->bindParam(':JSONB64CUSTOMMEDIA', $paramsImagens['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsImagens['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		
		else{
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_IMAGES);
			$statement->bindParam(':JSONB64CUSTOMMEDIA', $paramsImagens['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsImagens['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		
	}
	
	
	const CHECK_IMAGES = "
		SELECT 1 FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	const UPDATE_IMAGES = "
		UPDATE CUSTOMIZACAOTAAMOBILE
		SET JSONB64CUSTOMMEDIA = :JSONB64CUSTOMMEDIA
		WHERE NRORG = :NRORG
	";
	
	const INSERT_IMAGES =
		"INSERT INTO CUSTOMIZACAOTAAMOBILE
		(JSONB64CUSTOMMEDIA, NRORG)
		VALUES
		(:JSONB64CUSTOMMEDIA, :NRORG)
	";
	
	public function saveJsonConfig($jsonConfigString, $NRORG) {
	    $checaJsonConfig = $this->entityManager->getConnection()->fetchAll(self::CHECK_JSONCONFIG, ['NRORG' => $NRORG]);
	    if (isset($checaJsonConfig[0])) {
	        $statement = $this->entityManager->getConnection()->prepare(self::UPDATE_JSONCONFIG);
	        $statement->bindParam(':JSONCONFIG', $jsonConfigString, \PDO::PARAM_LOB);
	        $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	         // Executa a declaração
	    	$statement->execute();
	    } else {
	        $statement = $this->entityManager->getConnection()->prepare(self::INSERT_JSONCONFIG);
	        $statement->bindParam(':JSONCONFIG', $jsonConfigString, \PDO::PARAM_LOB);
	        $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	         // Executa a declaração
	    	$statement->execute();
	    }
	}
	
	public function findJsonConfig($nrOrg) {
	    // Prepara a consulta para buscar o JSON config
	    $statement = $this->entityManager->getConnection()->prepare(self::SELECT_JSONCONFIG);
	    $statement->bindParam(':NRORG', $nrOrg, \PDO::PARAM_INT);
	
	    // Executa a consulta
	    $statement->execute();
	
	    // Obtém o resultado
	    $result = $statement->fetch();

		$decode = json_decode($result['JSONCONFIG'], true);
		
		// tratativa de campos
		if (isset($decode['mainLanguage']) && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['name'])) {
			$decode['mainLanguageName'] = $decode['mainLanguage'][0]['name'];
		} else {
			$decode['mainLanguageName'] = "";
		}
		
		if (isset($decode['mainLanguage'])  && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['code'])) {
			$decode['mainLanguageCode'] = $decode['mainLanguage'][0]['code'];
		} else {
			$decode['mainLanguageCode'] = "";
		}
		
		if (isset($decode['modeEntregaDrive']) && !empty($decode['modeEntregaDrive'])) {
		    $decode['entregaDrive'] = true;
		} else if (isset($decode['modeEntrega']) && !empty($decode['modeEntrega'])) {
			$decode['entregaDrive'] = false;
		    $decode['entregaComer'] = in_array("comer", $decode['modeEntrega']);
		    $decode['entregaLevar'] = in_array("levar", $decode['modeEntrega']);
		} else {
			$decode['entregaDrive'] = false;
			$decode['entregaComer'] = false;
			$decode['entregaLevar'] = false;
		}

		
		foreach ($decode as $key => &$value) {
	        if (is_bool($value)) {
	            $value = $value ? "S" : "N";
	        }
		}
		
		$res = array();
		
		$res[] = $decode;

        return $result ? $res : null;
	}
	
	const SELECT_JSONCONFIG = "
	SELECT JSONCONFIG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	
	const CHECK_JSONCONFIG = "
		SELECT JSONCONFIG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";
	
	const UPDATE_JSONCONFIG = "
		UPDATE CUSTOMIZACAOTAAMOBILE
		    SET JSONCONFIG = :JSONCONFIG
		    WHERE NRORG = :NRORG
	";
	
	const INSERT_JSONCONFIG = "
		INSERT INTO CUSTOMIZACAOTAAMOBILE
			(JSONCONFIG, NRORG)
			VALUES
			(:JSONCONFIG, :NRORG)
	";
	
	
	
	public function findConfigsUnidadeLoja() {
		$statement = $this->entityManager->getConnection()->prepare(self::SELECTCUSTOMUNIDADE);
	    $statement->execute();
        return $statement->fetchAll();
    }
    
    
    public function GETNEWCOD() {
		$statement = $this->entityManager->getConnection()->prepare(self::GETCOD);
	    $statement->execute();
        return $statement->fetch();
    }
    
    
    public function saveConfigUnidade($row){
    	$statement = $this->entityManager->getConnection()->prepare(self::INSERTCUSTOMIZUNIDADELOJA);
		$statement->bindParam(':CDCONFIGTAA',	$row['CDCONFIGTAA'], \PDO::PARAM_STR);
		$statement->bindParam(':NMCONFIGTAA',	$row['NMCONFIGTAA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDFILIAL',	$row['CDFILIAL'], \PDO::PARAM_STR);
		$statement->bindParam(':CDLOJA',	$row['CDLOJA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDOPERULTATU',	$row['CDOPERULTATU'], \PDO::PARAM_STR);
		$statement->bindParam(':JSONB64CUSTOMMEDIA', $row['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
		$statement->bindParam(':JSONCONFIG', $row['JSONCONFIG'], \PDO::PARAM_LOB);
		
		$statement->bindParam(':DTULTATU',	$row['DTULTATU'], \PDO::PARAM_STR);
		$statement->bindParam(':IDATIVO',	$row['IDATIVO'], \PDO::PARAM_STR);
		$statement->bindParam(':DTINCLUSAO',	$row['DTINCLUSAO'], \PDO::PARAM_STR);
		$statement->bindParam(':CDOPERINCLUSAO',	$row['CDOPERINCLUSAO'], \PDO::PARAM_STR);

		return $statement->execute();
    }
    
    
    public function updateConfigUnidade($row){
        $params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':NMCONFIGTAA'  	=> $row['NMCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA'],
            ':CDOPERULTATU' 	=> $row['CDOPERULTATU'],
            ':DTULTATU' 		=> $row['DTULTATU']
 		);

 		return $this->entityManager->getConnection()->executeQuery(self::UPDATECUSTOMIZUNIDADELOJA, $params);
    }
    
    public function deleteConfigUnidade($row) {
        $params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA'],
 		);
 		$this->entityManager->getConnection()->executeQuery(self::DELETECAIXACUSTOMZUNIDADELOJA, $params);
 		return $this->entityManager->getConnection()->executeQuery(self::DELETECUSTOMZUNIDADELOJA, $params);
    }
    
    
    const SELECTCUSTOMUNIDADE = "
		SELECT C.CDCONFIGTAA, C.NMCONFIGTAA, C.CDFILIAL, F.NMFILIAL, C.CDLOJA, L.NMLOJA FROM CONFCUSTOMTAA C JOIN FILIAL F ON C.CDFILIAL = F.CDFILIAL JOIN LOJA L ON C.CDLOJA = L.CDLOJA AND C.CDFILIAL = L.CDFILIAL
	";
	
	const GETCOD = "
		SELECT NVL(LPAD(MAX(CDCONFIGTAA)+1,5,0),'00001') AS NEXT_CD FROM CONFCUSTOMTAA
	";
	
	const INSERTCUSTOMIZUNIDADELOJA = "
		INSERT INTO CONFCUSTOMTAA  (CDCONFIGTAA, NMCONFIGTAA, CDFILIAL, CDLOJA, CORESJSON, JSONCONFIG, JSONB64CUSTOMMEDIA, DTINCLUSAO, DTULTATU, CDOPERINCLUSAO, CDOPERULTATU, IDATIVO) VALUES (:CDCONFIGTAA, :NMCONFIGTAA, :CDFILIAL, :CDLOJA, null, :JSONCONFIG, :JSONB64CUSTOMMEDIA, :DTINCLUSAO, :DTULTATU, :CDOPERINCLUSAO, :CDOPERULTATU, :IDATIVO)
	";
	
	const UPDATECUSTOMIZUNIDADELOJA = "
		UPDATE CONFCUSTOMTAA SET NMCONFIGTAA = :NMCONFIGTAA, CDOPERULTATU = :CDOPERULTATU, DTULTATU = :DTULTATU WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const DELETECUSTOMZUNIDADELOJA = "
		DELETE FROM CONFCUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const DELETECAIXACUSTOMZUNIDADELOJA = "
		DELETE FROM CAIXACUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	
	
	const FIND_CORESUNIDADELOJA = "
    	SELECT CORESJSON, CDFILIAL, CDLOJA, CDCONFIGTAA FROM CONFCUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
    ";
    
    public function findCoresUnidadesLoja($row) {
        $params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA']
 		);
 		
 		return $this->entityManager->getConnection()->fetchAll(self::FIND_CORESUNIDADELOJA, $params);
    }
    
    
    const FIND_IMGSUNIDADESLOJA = "
    	SELECT JSONB64CUSTOMMEDIA, CDFILIAL, CDLOJA, CDCONFIGTAA FROM CONFCUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
    ";
    
    public function findImgsUnidadesLoja($row) {
        $params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA']
		 );
		 
		 return $this->entityManager->getConnection()->fetchAll(self::FIND_IMGSUNIDADESLOJA, $params);
    }
    
    
    public function saveColorsUnidadeLoja($paramsCores){
		
 		$checaCores = $this->entityManager->getConnection()->fetchAll(self::CHECK_UNIDADE, $paramsCores);
		if (isset(($checaCores[0][1]))){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_CORESUNIDADE);
		}
		else 
		{
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_CORESUNIDADE);
		}
		$statement->bindParam(':CORESJSON', $paramsCores['CORESJSON'], \PDO::PARAM_LOB);
		$statement->bindParam(':CDFILIAL',	$paramsCores['CDFILIAL'], \PDO::PARAM_STR);
		$statement->bindParam(':CDLOJA',	$paramsCores['CDLOJA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDCONFIGTAA',	$paramsCores['CDCONFIGTAA'], \PDO::PARAM_STR);
		return $statement->execute();
	}
	
	const CHECK_UNIDADE = "
		SELECT 1 FROM CONFCUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";

	const UPDATE_CORESUNIDADE = "
		UPDATE CONFCUSTOMTAA
			SET CORESJSON = :CORESJSON
			WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const INSERT_CORESUNIDADE =
		"INSERT INTO CONFCUSTOMTAA
			(CORESJSON, CDCONFIGTAA, CDFILIAL, CDLOJA)
		VALUES
			(:CORESJSON, :CDCONFIGTAA, :CDFILIAL, :CDLOJA)
	";
	
	
	
	
	public function saveImagensUnidadeLoja($paramsImagens){
		$checaImagens = $this->entityManager->getConnection()->fetchAll(self::CHECK_UNIDADE, $paramsImagens);
		if(isset($checaImagens[0][1])){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_IMAGESUNIDADE);
		}
		else{
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_IMAGESUNIDADE);
		}
		
		$statement->bindParam(':JSONB64CUSTOMMEDIA', $paramsImagens['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
		$statement->bindParam(':CDFILIAL',	$paramsImagens['CDFILIAL'], \PDO::PARAM_STR);
		$statement->bindParam(':CDLOJA',	$paramsImagens['CDLOJA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDCONFIGTAA',	$paramsImagens['CDCONFIGTAA'], \PDO::PARAM_STR);
		return $statement->execute();
	}

	const UPDATE_IMAGESUNIDADE = "
		UPDATE CONFCUSTOMTAA
			SET JSONB64CUSTOMMEDIA = :JSONB64CUSTOMMEDIA
			WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const INSERT_IMAGESUNIDADE =
		"INSERT INTO CONFCUSTOMTAA
			(JSONB64CUSTOMMEDIA, CDCONFIGTAA, CDFILIAL, CDLOJA)
		VALUES
			(:JSONB64CUSTOMMEDIA, :CDCONFIGTAA, :CDFILIAL, :CDLOJA)
	";
	
	public function saveJsonConfigUnidade($paramsConfig) {

		$paramsUnidade = array(
            ':CDCONFIGTAA'  	=> $paramsConfig['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $paramsConfig['CDFILIAL'],
            ':CDLOJA'			=> $paramsConfig['CDLOJA']
		 );
		 
 		$checaUnidade = $this->entityManager->getConnection()->fetchAll(self::CHECK_UNIDADE, $paramsUnidade);
	    if (isset($checaUnidade[0])) {
	        $statement = $this->entityManager->getConnection()->prepare(self::UPDATE_JSONCONFIGUNIDADE);
	    } else {
	        $statement = $this->entityManager->getConnection()->prepare(self::INSERT_JSONCONFIGUNIDADE);
	    }
	    $statement->bindParam(':JSONCONFIG', $paramsConfig['JSONCONFIG'], \PDO::PARAM_LOB);
		$statement->bindParam(':CDFILIAL',	$paramsConfig['CDFILIAL'], \PDO::PARAM_STR);
		$statement->bindParam(':CDLOJA',	$paramsConfig['CDLOJA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDCONFIGTAA',	$paramsConfig['CDCONFIGTAA'], \PDO::PARAM_STR);
	    $statement->execute();
	}
	
	public function findJsonConfigUnidade($paramsConfig) {
	    // Prepara a consulta para buscar o JSON config
	    $statement = $this->entityManager->getConnection()->prepare(self::SELECT_JSONCONFIGUNIDADE);
	    $statement->bindParam(':CDFILIAL',	$paramsConfig['CDFILIAL'], \PDO::PARAM_STR);
		$statement->bindParam(':CDLOJA',	$paramsConfig['CDLOJA'], \PDO::PARAM_STR);
		$statement->bindParam(':CDCONFIGTAA',	$paramsConfig['CDCONFIGTAA'], \PDO::PARAM_STR);
	
	    // Executa a consulta
	    $statement->execute();
	
	    // Obtém o resultado
	    $result = $statement->fetch();
		
		if($result){
			$decode = json_decode($result['JSONCONFIG'], true);
			
			// tratativa de campos
			if (isset($decode['mainLanguage']) && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['name'])) {
				$decode['mainLanguageName'] = $decode['mainLanguage'][0]['name'];
			} else {
				$decode['mainLanguageName'] = "";
			}
			
			if (isset($decode['mainLanguage'])  && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['code'])) {
				$decode['mainLanguageCode'] = $decode['mainLanguage'][0]['code'];
			} else {
				$decode['mainLanguageCode'] = "";
			}
			
			if (isset($decode['modeEntregaDrive']) && !empty($decode['modeEntregaDrive'])) {
			    $decode['entregaDrive'] = true;
			} else if (isset($decode['modeEntrega']) && !empty($decode['modeEntrega'])) {
				$decode['entregaDrive'] = false;
			    $decode['entregaComer'] = in_array("comer", $decode['modeEntrega']);
			    $decode['entregaLevar'] = in_array("levar", $decode['modeEntrega']);
			} else {
				$decode['entregaDrive'] = false;
				$decode['entregaComer'] = false;
				$decode['entregaLevar'] = false;
			}
	
			
			foreach ($decode as $key => &$value) {
		        if (is_bool($value)) {
		            $value = $value ? "S" : "N";
		        }
			}
			
			$res = array();
			
			$res[] = $decode;
			return $res;
		}
		else{
			return [];
		}
		

        
	}
	
	const SELECT_JSONCONFIGUNIDADE = "
		SELECT JSONCONFIG FROM CONFCUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const UPDATE_JSONCONFIGUNIDADE = "
		UPDATE CONFCUSTOMTAA
		    SET JSONCONFIG = :JSONCONFIG
		    WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA
	";
	
	const INSERT_JSONCONFIGUNIDADE = "
		INSERT INTO CONFCUSTOMTAA
			(JSONCONFIG, CDCONFIGTAA, CDFILIAL, CDLOJA)
		VALUES
			(:JSONCONFIG, :CDCONFIGTAA, :CDFILIAL, :CDLOJA)
	";
	
	
	public function findConfigsCaixas($row) {
        $params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA']
 		);
 		
 		return $this->entityManager->getConnection()->fetchAll(self::SELECT_CAIXACONFIG, $params);
    }
	const SELECT_CAIXACONFIG = "
		SELECT CC.CDCONFIGTAA, CX.NMCAIXA, CC.CDFILIAL, CC.CDLOJA, CC.CDCAIXA, CX.NRORG  FROM CAIXACUSTOMTAA CC JOIN CAIXA CX ON CC.CDFILIAL = CX.CDFILIAL AND CC.CDCAIXA = CX.CDCAIXA JOIN CONFCUSTOMTAA CG ON CC.CDFILIAL = CG.CDFILIAL AND CC.CDCONFIGTAA = CG.CDCONFIGTAA WHERE CC.CDFILIAL = :CDFILIAL AND CC.CDCONFIGTAA = :CDCONFIGTAA AND CC.CDLOJA = :CDLOJA ORDER BY CDFILIAL, CDLOJA, CDCAIXA, NMCAIXA
	";
	
	
	public function findCaixa($row){
		$params = array(
            ':CDCONFIGTAA'  	=> $row['CDCONFIGTAA'],
            ':CDFILIAL'     	=> $row['CDFILIAL'],
            ':CDLOJA'			=> $row['CDLOJA'],
            ':CDCAIXA'			=> $row['CDCAIXA']
 		);
 		
 		return $this->entityManager->getConnection()->fetchAll(self::FIND_CAIXACONF, $params);
	}
	
	const FIND_CAIXACONF = "
		SELECT COUNT(*) as QTD FROM CAIXACUSTOMTAA WHERE CDCONFIGTAA = :CDCONFIGTAA AND CDFILIAL = :CDFILIAL AND CDLOJA = :CDLOJA AND CDCAIXA = :CDCAIXA
	";
}