<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\NovoCodigo;
use Teknisa\MAN\Factories\ImportacaoCatracaFactories;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class ImportacaoCatracaServices {
    
    protected $entityManager;
    protected $importFactories;

	public function __construct(EntityManager $entityManager, ImportacaoCatracaFactories $importFactories) {
        $this->entityManager = $entityManager;
        $this->importFactories = $importFactories;
    }
    
    public function findFilial($conditions){
        $query = $this->entityManager->getConnection()->fetchAll(Utilities\Query::FIND_LOGCATRACA, $conditions);

        if(is_bool($query)){
            $query  = [];
        }else{
            $pos = array();
            $fields = ['IDCATLOGCAT', 'IDCRAHABFILI', 'IDCRALOGCAT', 'IDDATLOGCAT', 'IDDUPLOGCAT', 'IDPROLOGCAT', 'IDSERLOGCAT'];
            
            foreach($query as $index => &$row){
                foreach($row as $field => &$value ){
                    if(in_array($field, $fields)){
                        if ($value === '3'){
                            $value = 'Valor inválido';
                        }else if($value === '2'){
                            $value = 'OK';
                        }else if($value === '1'){
                            $value = 'Não verificado';
                        }
                    }
                }
            }
        }

        return $query;
    }
    
    public function insertDadosCatraca($rows, $response){
        $params = array(); //PARAMETROS
        $IDREGDUPLICADO = array(); // CONTROLE PARA IDREGDUPLICADO DUPLICADO
        $crachaDuplicado = array(); // CONTROLE PARA CRACHÁ DUPLICADO (IDDUPLOGCAT)
        
        $base64 = explode(",", $rows['ARQEXCEL'][0]['b64File']);
        $data = base64_decode($base64[1]);
        $dataArray = explode(PHP_EOL, $data);

        $NRSEQARQIMP = 0; //SIZE = 10
        $params['NMARQLOGCAT'] = $rows['ARQEXCEL'][0]['name']; //ARQUIVO
        $params['CDOPERADOR'] = $rows['CDOPERADOR']; //NOME OPERADOR
        $params['CDFILIAL'] = $rows['CDFILIAL']; //CÓDIGO FILIAL
        $params['DTINI'] = $rows['DTINI'];
        $params['DTFIN'] = $rows['DTFIN'];
        
        $conditions = [
            'CDLAYOUTIMP' => $rows['CDLAYOUTIMP'],
            'NRSEQTABELAY' => $rows['NRSEQTABELAY'],
            'IDFUNARQLAY' => '010'
        ];
        
        // LAYOUT
        $layoutCatraca = $this->importFactories->getCamposLayout($conditions);
        $operador= $this->importFactories->getNmOper($params);
        $params['NMOPERADOR'] = $operador['NMOPERADOR'];
        try{
            $connection = $this->entityManager->getConnection();
            #starts transaction of current loop
            $connection->beginTransaction();
            
            foreach($dataArray as $data => $line){
                if(!empty($line)){
                    ++$NRSEQARQIMP;
                    $params['NRSEQARQIMP'] = str_pad($NRSEQARQIMP, 10, "0", STR_PAD_LEFT);
                    $Query = 'INSERT INTO LOGCATRACA
                        (CDFILIAL, NRSEQLOGCAT, IDSIMPLOGCAT, IDCRALOGCAT , IDCATLOGCAT, IDDATLOGCAT, IDSERLOGCAT, DTIMPLOGCAT, CDOPERADOR, DSOBSLOGCAT, NMARQLOGCAT, NRSEQARQIMP, IDREGDUPLICADO, IDDUPLOGCAT, IDCRAHABFILI, IDPROLOGCAT %COLUNA%)
                      VALUES
                        (:CDFILIAL, :NRSEQLOGCAT, :IDSIMPLOGCAT, :IDCRALOGCAT, :IDCATLOGCAT, :IDDATLOGCAT, :IDSERLOGCAT, SYSDATE , :CDOPERADOR, :DSOBSLOGCAT, :NMARQLOGCAT, :NRSEQARQIMP, :IDREGDUPLICADO, :IDDUPLOGCAT, :IDCRAHABFILI, :IDPROLOGCAT %VALORES%)';
                    $colunas  = [];
                    
                    foreach($layoutCatraca as $layout){
                        $params[$layout['NMCOLUNA']] = substr($line, ($layout['NRPOSICOLLAY']-1), $layout['NRTAMCOLLAY']);
                        if($layout['IDCOLUNANULL'] == 'N' and ($params[$layout['NMCOLUNA']] == '')){
                            throw new \Exception("A coluna ".$layout['NMCOLUNA']." não pode receber valor nulo.");
                        }
                        if($layout['NMCOLUNA'] == 'DSDTHRLOGCAT'){
                            $params['DSFRMTCOLLAY'] = $layout['DSFRMTCOLLAY'];
                        }
                        if(!strpos($Query, $layout['NMCOLUNA'])){
                            $colunas[] = $layout['NMCOLUNA'];
                        }
                    }
                    
                    if(isset($params['CDCONSUMIDOR'])){
                        
                        $CONDITION[':CDCONSUMIDOR'] = $params['CDCONSUMIDOR'] = str_pad($params['CDCONSUMIDOR'], 21, "0", STR_PAD_LEFT);
                        $CDIDCONSUMID = $this->importFactories->getCDIDCONSUMID($CONDITION);
                        
                        if(isset($CDIDCONSUMID['CDIDCONSUMID'])){
                            if($CDIDCONSUMID['CDIDCONSUMID'] != $params['NRIDENLOGCAT']){
                                throw new \Exception("Código do crachá do consumidor ".$params['CDCONSUMIDOR']." não compatível com o parametrizado no banco!");
                            }
                        } else {
                            throw new \Exception("Código do crachá do consumidor ".$params['CDCONSUMIDOR']." não encontrado no banco!");
                        }

                    }
                    
                    if(isset($params['CDCAIXLOGCAT'])){
                        $params['CDCAIXLOGCAT'] = str_pad($params['CDCAIXLOGCAT'], 3, "0", STR_PAD_LEFT);
                    }
                    
                    if(isset($params['DSDTHRLOGCAT']) && isset($params['DSFRMTCOLLAY'])){
                        $params['DSDTHRLOGCAT'] = date("d/m/Y H:i:s", strtotime(str_replace('/', '-', $this->formatDATE($params['DSFRMTCOLLAY'], $params['DSDTHRLOGCAT']))));
                    }
                    
                    $Query = str_replace('%COLUNA%', ', '.join(', ', $colunas), $Query); 
                    $Query = str_replace('%VALORES%', ', :'.join(', :', $colunas), $Query); 
                    
                    $params['DSOBSLOGCAT'] = $params['CDCAIXLOGCAT']. ' - ' .$params['NRIDENLOGCAT']. ' - ' .$params['NMOPERADOR'];
                    $params['NRSEQLOGCAT'] = NovoCodigo::geraCodigo($this->entityManager->getConnection(), 'LOGCATRACA'.$params['CDFILIAL'], 1, 10);

                    // IDREGDUPLICADO = Verifica se o registro veio duplicado no arquivo (com todos os campos iguais). Se encontrar duplicidade, insere 'S', senão 'N'.
                    $chave = $params['CDCAIXLOGCAT'].$params['CDFILIAL'].$params['NRIDENLOGCAT'].$params['NMOPERADOR'];
                    if(in_array($chave, $IDREGDUPLICADO)){
                        $params['IDREGDUPLICADO'] = 'S';
                    }else{
                        $params['IDREGDUPLICADO'] = 'N';
                        $IDREGDUPLICADO[] = $chave;
                    }
                    
                    //IDENTIFICADORES
                    $params['IDSIMPLOGCAT'] = 'P'; //Identificador da situação do registro de log da importação da catraca - 'P' pendente - 'I' importado
                    $params['IDDATLOGCAT'] = '1'; //Identificador da situação do formato da data/hora - '1' Não validado - '2' Ok - '3' Formato de data/hora inválido

                    
                    // CRACHÁ
                    $this->getIDCRALOGCAT($params);
                    
                    // o campo 'Crachá duplicado' (IDDUPLOGCAT) é '3', quando existem crachás (NRIDENLOGCAT) iguais nos clientes da filial 
                    if(in_array($params['NRIDENLOGCAT'], $crachaDuplicado)){
                        $params['IDDUPLOGCAT'] = '3'; // CRACHÁ JÁ EXISTE
                    }else{
                        $params['IDDUPLOGCAT'] = '2'; // CRACHÁ OK
                        $crachaDuplicado[] = $params['NRIDENLOGCAT'];
                    }
                    
                    //o campo 'Habilitado filial' (IDCRAHABFILI) é '3' para Crachá não habilitado, se o crachá não estiver habilitado para a filial. E '2' para crachá habilitado
                    $params['IDCRAHABFILI'] = $params['IDCRALOGCAT'];
                    
                    // CRATRACA
                    $this->getCAIXA($params);
                    
                    // SERVIÇO
                    $this->getIDSERLOGCAT($params);
                    
                    // PRODUTO
                    $this->getIDPROLOGCAT($params);
                    
                    // CHAMADA DO INSERT
                    $this->importFactories->insertDadosCatraca($params, $Query);
                }
            }
            
            $this->importFactories->validCatracas($params);
            $CDEMPRESA = $this->importFactories->getCDEMPRESA($params);
            
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'GERA_VENDA_CATRACA');
            $procedure->addParam(new Param('P_CDFILIAL'  , Param::PARAM_INPUT , $params['CDFILIAL'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDOPERADOR'  , Param::PARAM_INPUT , $params['CDOPERADOR'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDEMPRESA'  , Param::PARAM_INPUT , $CDEMPRESA['CDEMPRESA'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINI'  , Param::PARAM_INPUT , $params['DTINI'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTFIN'  , Param::PARAM_INPUT , $params['DTFIN'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDCLIENTE'  , Param::PARAM_INPUT , null, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDCONSUMIDOR'  , Param::PARAM_INPUT , null, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_OPERADOR'  , Param::PARAM_INPUT , $params['CDOPERADOR'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_ERRO'  , Param::PARAM_INPUT , null, Param::PARAM_TYPE_STR));
            $procedure->execute();
            
            
			$this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function formatDATE($format, $date){
        
        // Contagem dos caracteres Y, M, D, H, N, S no formato
        
        $countCaracter = [
            'ANO' =>  substr_count($format, 'Y'),
            'MES' =>  substr_count($format, 'M'),
            'DIA' =>  substr_count($format, 'D'),
            'HOR' =>  substr_count($format, 'S'),
            'MIN' =>  substr_count($format, 'N'),
            'SEC' =>  substr_count($format, 'H')
        ];
        
        $DATA = '';
        
        foreach($countCaracter as $momento => $value){
            if($momento == 'ANO'){
                $DATA = '20'.substr($date, strpos($format, 'Y'), $value);
            } else if($momento == 'MES'){
                $DATA = $DATA.substr($date, strpos($format, 'M'), $value);
            } else if($momento == 'DIA'){
                $DATA = $DATA.substr($date, strpos($format, 'D'), $value);
            } else if($momento == 'HOR'){
                $DATA = $DATA.substr($date, strpos($format, 'H'), $value);
            } else if($momento == 'MIN'){
                $DATA = $DATA.substr($date, strpos($format, 'N'), $value);
            } else if($momento == 'SEC'){
                $DATA = $DATA.substr($date, strpos($format, 'S'), $value);
            }
        }
        
        return $DATA;
    }
    
    public function getIDCRALOGCAT(&$params){
        // IDCRALOGCAT -> CRACHÁ
        $param = [
            'NRIDENLOGCAT'  =>  $params['NRIDENLOGCAT'],
            'CDFILIAL'      =>  $params['CDFILIAL']
        ];
        
        $params['IDCRALOGCAT'] = $this->importFactories->getIDCRALOGCAT($param);
    }
    
    public function getCAIXA(&$params){
        //o campo 'Catraca' (IDCATLOGCAT) é '3' Código da catraca inválido, se o caixa for inválido. E '2' se o caixa for válido
        $param = [
            'CDCAIXA'   =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'  =>  $params['CDFILIAL']
        ];
        
        $params['IDCATLOGCAT'] = $this->importFactories->getCAIXA($param);
    }
    
    public function getIDSERLOGCAT(&$params){
        // o campo 'Serviço' é alterado para '3' Horário sem serviço definido, se o serviço não for encontrado
        $param = [
            'CDCAIXA'           =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'          =>  $params['CDFILIAL'],
            'DSDTHRLOGCAT'      =>  $params['DSDTHRLOGCAT']
        ];
        
        $params['IDSERLOGCAT'] = $this->importFactories->getIDSERLOGCAT($param);
    }
    
    public function getIDPROLOGCAT(&$params){
       // o campo 'Produto' (IDPROLOGCAT) é '3' Produto Inválido, se o produto não for encontrado
        $param = [
            'CDCAIXA'           =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'          =>  $params['CDFILIAL'],
            'DSDTHRLOGCAT'      =>  $params['DSDTHRLOGCAT']
        ];
        
        $params['IDPROLOGCAT'] = $this->importFactories->getIDPROLOGCAT($param);
    }
    
    public function deleteRowLogCatraca($params){
        $this->importFactories->deleteRowLogCatraca($params);
    }
    
    public function findConfigLayout(){
        return $this->entityManager->getConnection()->fetchAll(Utilities\Query::FIND_CONFIG_LAYOUT);
    }
    
}